@@ -3,10 +3,11 @@ package Padre::Plugin::PerlTidy;
 use strict;
 use warnings;
 
-use Perl::Tidy ();
-use Wx qw(wxOK wxCENTRE);
+use base 'Padre::Plugin';
 
-our $VERSION = '0.01';
+use Padre::Wx ();
+
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -22,25 +23,29 @@ file if it exists (see Perl::Tidy documentation).
 
 =cut
 
-my @menu = (
-    [ 'Tidy the active document', \&tidy_document ],
-    [ 'Tidy the selected text',   \&tidy_selection ]
-);
+sub padre_interfaces {
+	'Padre::Plugin' => '0.18',
+}
 
-sub menu {
-    return @menu;
+sub menu_plugins_simple {
+    PerlTidy => [
+        'Tidy the active document' => \&tidy_document,
+        'Tidy the selected text'   => \&tidy_selection,
+    ];
 }
 
 sub _tidy {
     my ( $self, $src ) = @_;
 
+    require Perl::Tidy;
+
     return unless defined $src;
 
     my $doc = $self->selected_document;
 
     if ( !$doc->isa( 'Padre::Document::Perl' ) ) {
         return Wx::MessageBox( 'Document is not a Perl document',
-            "Error", wxOK | wxCENTRE, $self );
+            "Error", Wx::wxOK | Wx::wxCENTRE, $self );
     }
 
     my ( $output, $stderr );
@@ -60,7 +65,7 @@ sub _tidy {
         Wx::MessageBox(
             $error_string,
             "PerlTidy Error",
-            wxOK | wxCENTRE, $self
+            Wx::wxOK | Wx::wxCENTRE, $self
         );
         return;
     }
@@ -96,15 +101,39 @@ sub tidy_document {
     $doc->text_set( $newtext );
 }
 
-=head1 AUTHOR
+=head1 INSTALLATION
 
-Patrick Donelan
+You can install this module like any other Perl module and it will
+become available in your Padre editor. However, you can also
+choose to install it into your user's Padre configuration directory only:
+
+=over 4
+
+=item * Install the prerequisite modules.
+
+=item * perl Makefile.PL
+
+=item * make
+
+=item * make installplugin
+
+=back
+
+This will install the plugin as PerlTidy.par into your user's ~/.padre/plugins
+directory.
+
+Similarly, "make plugin" will just create the PerlTidy.par which you can
+then copy manually.
+
+=head1 AUTHOR
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
+Patrick Donelan
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 by Patrick Donelan http://www.patspam.com
+Copyright 2008 by Patrick Donelan, Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
